@@ -137,8 +137,8 @@ class TektonCompiler(Compiler):
     self.custom_task_crs = []
     self.uuid = self._get_unique_id_code()
     self._group_names = []
-    self.pipeline_labels = {}
-    self.pipeline_annotations = {}
+    self.pipeline_labels = {'pipelines.kubeflow.org/pipelinename': '', 'pipelines.kubeflow.org/generation': ''}
+    self.pipeline_annotations = {'tekton.dev/template': ''}
     self.tekton_inline_spec = True
     self.resource_in_separate_yaml = False
     self.produce_taskspec = True
@@ -1025,12 +1025,18 @@ class TektonCompiler(Compiler):
             container_args = i.get('args', [])
             custom_task_command = {}
             container_command = i.get('command', [])
-            for index, item in enumerate(container_args):
-              if item.startswith('--'):
-                custom_task_args[item[2:]] = container_args[index + 1]
-            for index, item in enumerate(container_command):
-              if item.startswith('--'):
-                custom_task_command[item[2:]] = container_command[index + 1]
+
+            def find_parameter(arg_list, arg_task_list):
+              skip_index = False
+              for index, item in enumerate(arg_list):
+                if skip_index:
+                  skip_index = False
+                  continue
+                if item.startswith('--'):
+                  arg_task_list[item[2:]] = arg_list[index + 1]
+                  skip_index = True
+            find_parameter(container_args, custom_task_args)
+            find_parameter(container_command, custom_task_command)
             non_param_keys = ['name', 'apiVersion', 'kind', 'taskSpec', 'taskRef']
             task_params = []
             command_params = []
@@ -1610,6 +1616,11 @@ class TektonCompiler(Compiler):
     if pipeline_conf and pipeline_conf.data_passing_method is not None:
       workflow = fix_big_data_passing_using_volume(workflow, pipeline_conf)
 
+    if pipeline_conf and pipeline_conf.timeout > 0:
+      workflow['spec'].setdefault('timeouts', {'pipeline': '0s', 'tasks': '0s'})
+      workflow['spec']['timeouts']['tasks'] = '%ds' % pipeline_conf.timeout
+      workflow['spec']['timeouts']['pipeline'] = '%ds' % (pipeline_conf.timeout + DEFAULT_FINALLY_SECONDS)
+
     workflow.setdefault('metadata', {}).setdefault('annotations', {})['pipelines.kubeflow.org/pipeline_spec'] = \
       json.dumps(pipeline_meta.to_dict(), sort_keys=True)
 
